from .item import *
from ._internal import *
from ._data import *
from .attachments import *

import atexit


parse()


atexit.register(Launch.finish_launch)


__all__ = (item.__all__ +
           attachments.__all__)




__all__ = ['attachment_type']


class attachment_type:
    PNG = 'image/png'
    JPEG = 'image/jpeg'
    TXT = 'text/plain'
    JSON = 'application/json'
    YAML = 'application/json'
    PDF = 'application/pdf'
    PCAP = 'application/vnd.tcpdump.pcap'


from setuptools import setup, find_packages

setup(
    name='report-dh',
    version='0.13.2',
    packages=find_packages(),
    entry_points={
        'pytest11': [
            'report=report.plugin'
        ],
        'console_scripts': [
            'report-dh=report._config:config'
        ]
    },
    install_requires=[
        'requests',
        'pytest'
    ],
    python_requires='>=3.7, <4',
    description='Report Portal API',
    long_description='Report Portal API Wrapper',
    license='MIT License',
    author='Deyaa Hojerat',
    author_email='deyaa.hojerat.98@gmail.com',
    url='https://github.com/deyaa562/Report',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Framework :: Pytest'
    ],
    addopts='-p report'
)